@@ -1,4 +1,4 @@
-from typing import Optional, Type, Dict, Tuple
+from typing import Optional, Type, Dict, Tuple, List
 
 from vatis.asr_commons.config.logging import get_logger
 
@@ -10,8 +10,9 @@ from .consumer import ConsumerManager, Consumer
 from .exceptions import ConnectionClosedException, NoRouteFoundException, RetriesExceededException
 from .model import DEFAULT_EXCHANGE, Queue, Exchange, TRANSCRIPTION_RESULT_WAITING_EXCHANGE
 from .publisher import Publisher
-from .routing import RoutingRule
+from .routing import RoutingRule, Route
 from . import consumer
+from . import headers
 
 logger = get_logger(__name__)
 _initialized = False
@@ -63,11 +64,17 @@ def _declare_waiting_transcription_result_exchange(connection: ReconnectingAMQPC
                                  durable=TRANSCRIPTION_RESULT_WAITING_EXCHANGE.durable)
 
 
-def push(message, ttl_millis: Optional[int] = environment.RABBITMQ_TTL_MILLIS):
-
+def push(message, ttl_millis: Optional[int] = None, headers: Dict[str, str] = None):
     from .publisher import publisher
 
-    publisher.push(message, ttl_millis=ttl_millis)
+    publisher.push(message, ttl_millis=ttl_millis, headers=headers)
+
+
+def push_to_routes(message, routes: List[Route], ttl_millis: Optional[int] = None,
+                   headers: Dict[str, str] = None):
+    from .publisher import publisher
+
+    publisher.push_to_routes(message, routes=routes, ttl_millis=ttl_millis, headers=headers)
 
 
 def close():
@@ -75,10 +82,11 @@ def close():
     consumer.close()
 
 
-def consume(queue: Queue, dtype: Optional[Type] = None, exchange: Exchange = DEFAULT_EXCHANGE):
+def consume(queue: Queue, dtype: Optional[Type] = None, exchange: Exchange = DEFAULT_EXCHANGE, auto_ack: bool = True):
     """
     Conventional decorator
 
+    :param auto_ack: automatically ack the message. See @Consumer for details
     :param queue: queue to be consumed
     :param dtype: expected payload type
     :param exchange: exchange to bind the queue to
@@ -87,7 +95,7 @@ def consume(queue: Queue, dtype: Optional[Type] = None, exchange: Exchange = DEF
     def decorator(func):
         from .consumer import consumer_manager
 
-        queue_consumer = Consumer(queue=queue, exchange=exchange, dtype=dtype, callback=func)
+        queue_consumer = Consumer(queue=queue, exchange=exchange, dtype=dtype, callback=func, auto_ack=auto_ack)
         consumer_manager.add_consumer(queue_consumer)
 
     return decorator
